@@ -2,8 +2,9 @@
 #include <stdio.h>
 #include "app-helpers.h"
 #include "nt-stuff.h"
+#include "util/base.h"
 
-WINADVAPI WINAPI ConvertSidToStringSidW(PSID sid, LPWSTR *str);
+WINADVAPI BOOL WINAPI ConvertSidToStringSidW(PSID sid, LPWSTR *str);
 
 bool is_app(HANDLE process)
 {
@@ -12,12 +13,10 @@ bool is_app(HANDLE process)
 	HANDLE token;
 
 	if (OpenProcessToken(process, TOKEN_QUERY, &token)) {
-		BOOL success = GetTokenInformation(token, TokenIsAppContainer,
-						   &ret, sizeof(ret),
-						   &size_ret);
+		BOOL success = GetTokenInformation(token, TokenIsAppContainer, &ret, sizeof(ret), &size_ret);
 		if (!success) {
-			DWORD error = GetLastError();
-			int test = 0;
+			const DWORD error = GetLastError();
+			blog(LOG_ERROR, "is_app GetTokenInformation failed: 0x%08lX", error);
 		}
 
 		CloseHandle(token);
@@ -33,13 +32,11 @@ wchar_t *get_app_sid(HANDLE process)
 	HANDLE token;
 
 	if (OpenProcessToken(process, TOKEN_QUERY, &token)) {
-		DWORD info_len = GetSidLengthRequired(12) +
-				 sizeof(TOKEN_APPCONTAINER_INFORMATION);
+		DWORD info_len = GetSidLengthRequired(12) + sizeof(TOKEN_APPCONTAINER_INFORMATION);
 
 		PTOKEN_APPCONTAINER_INFORMATION info = malloc(info_len);
 
-		success = GetTokenInformation(token, TokenAppContainerSid, info,
-					      info_len, &size_ret);
+		success = GetTokenInformation(token, TokenAppContainerSid, info, info_len, &size_ret);
 		if (success)
 			ConvertSidToStringSidW(info->TokenAppContainer, &ret);
 
@@ -50,8 +47,7 @@ wchar_t *get_app_sid(HANDLE process)
 	return ret;
 }
 
-static const wchar_t *path_format =
-	L"\\Sessions\\%lu\\AppContainerNamedObjects\\%s\\%s";
+static const wchar_t *path_format = L"\\Sessions\\%lu\\AppContainerNamedObjects\\%s\\%s";
 
 HANDLE create_app_mutex(const wchar_t *sid, const wchar_t *name)
 {
